@@ -228,37 +228,40 @@ static gint pv_img_set_psw_addr(PvImage *img, const gchar *psw_addr_s,
 	return 0;
 }
 
-static gint pv_img_set_control_flags(PvImage *img, const gchar *pcf_s,
-				     const gchar *scf_s,
-				     PvTristate allow_dump,
-				     PvTristate allow_pckmo, GError **err)
+static void pv_img_set_control_flag(uint64_t *flags, const PvTristate option, const uint64_t flag)
+{
+	if (option == PV_TRUE)
+		*flags |= flag;
+	else if (option == PV_FALSE)
+		*flags &= ~flag;
+}
+
+static gint pv_img_set_control_flags(PvImage *img, const PvControlFlagsArgs *cf_args, GError **err)
 {
 	uint64_t flags;
 
-	if (pcf_s) {
-		if (hex_str_toull(pcf_s, &flags, err) < 0)
+	/* Set plain control flags */
+	if (cf_args->pcf) {
+		if (hex_str_toull(cf_args->pcf, &flags, err) < 0)
 			return -1;
 
 		img->pcf = flags;
 	}
 
-	if (scf_s) {
-		if (hex_str_toull(scf_s, &flags, err) < 0)
+	pv_img_set_control_flag(&img->pcf, cf_args->enable_dump, PV_PCF_ALLOW_DUMPING);
+	pv_img_set_control_flag(&img->pcf, cf_args->enable_pckmo,
+				PV_PCF_PCKM_ECC | PV_PCF_PCKMO_AES | PV_PCF_PCKMO_DEA_TDEA);
+
+	/* Set secret control flags */
+	if (cf_args->scf) {
+		if (hex_str_toull(cf_args->scf, &flags, err) < 0)
 			return -1;
 
 		img->scf = flags;
 	}
 
-	if (allow_dump == PV_TRUE)
-		img->pcf |= PV_PCF_ALLOW_DUMPING;
-	else if (allow_dump == PV_FALSE)
-		img->pcf &= ~PV_PCF_ALLOW_DUMPING;
-
-	if (allow_pckmo == PV_TRUE)
-		img->pcf |= PV_PCF_PCKM_ECC | PV_PCF_PCKMO_AES | PV_PCF_PCKMO_DEA_TDEA;
-	else if (allow_pckmo == PV_FALSE)
-		img->pcf &= ~(PV_PCF_PCKM_ECC | PV_PCF_PCKMO_AES | PV_PCF_PCKMO_DEA_TDEA);
-
+	pv_img_set_control_flag(&img->scf, cf_args->enable_cck_extension_secret_enforcement,
+				PV_SCF_CCK_EXTENSION_SECRET_ENFORCMENT);
 	return 0;
 }
 
@@ -610,9 +613,7 @@ PvImage *pv_img_new(PvArgs *args, const gchar *stage3a_path, GError **err)
 		return NULL;
 
 	/* set the control flags: PCF and SCF */
-	if (pv_img_set_control_flags(ret, args->pcf, args->scf,
-				     args->allow_dump, args->allow_pckmo,
-				     err) < 0)
+	if (pv_img_set_control_flags(ret, &args->cf_args, err) < 0)
 		return NULL;
 
 	/* read in the keys */
